/********************************************************************
 File: usb_config.c

 Description:
 This file contains the main logic of the USBStickLogger project.
 USBStickLogger records serial data received from the UART on the
 connected USB thumb drive.

 Authors and Copyright:
 (c) 2011, Thomas Fischl <tfischl@gmx.de>

 Device: PIC24FJ64GB002
 Compiler: C30

 License:
 This file is open source. You can use it or parts of it in own
 open source projects. For closed or commercial projects you have to
 contact the authors listed above to get the permission for using
 this source code.

 This firmware uses libraries provided by Microchip. Please read the
 software licence agreement in the particular file for further
 information if you intend to use parts of this library in your own
 programs.
 
********************************************************************/

#include "GenericTypeDefs.h"
#include "HardwareProfile.h"
#include "USB\usb.h"
#include "USB\usb_host_msd.h"
#include "USB\usb_host_msd_scsi.h"

// *****************************************************************************
// Media Interface Function Pointer Table for the Mass Storage client driver
// *****************************************************************************

CLIENT_DRIVER_TABLE usbMediaInterfaceTable =
{                                           
    USBHostMSDSCSIInitialize,
    USBHostMSDSCSIEventHandler,
    0
};

// *****************************************************************************
// Client Driver Function Pointer Table for the USB Embedded Host foundation
// *****************************************************************************

CLIENT_DRIVER_TABLE usbClientDrvTable[] =
{                                        
    {
        USBHostMSDInitialize,
        USBHostMSDEventHandler,
        0
    }
};

// *****************************************************************************
// USB Embedded Host Targeted Peripheral List (TPL)
// *****************************************************************************

USB_TPL usbTPL[] =
{
    { INIT_CL_SC_P( 8ul, 6ul, 0x50ul ), 0, 0, {TPL_CLASS_DRV} } // Thumbdrives
};

